/**
 * @since 1.0.0
 */
import * as Schema from "@effect/schema/Schema";
/**
 * A wireguard key, which is a 44 character base64 string.
 *
 * @see {@link generateKeyPair}
 *
 * @since 1.0.0
 * @category Datatypes
 * @see https://lists.zx2c4.com/pipermail/wireguard/2020-December/006222.html
 */
export declare const WireguardKey: Schema.brand<Schema.Schema<string, string, never>, "WireguardKey">;
/** @since 1.0.0 */
export type WireguardKey = Schema.Schema.Type<typeof WireguardKey>;
/**
 * Generates a wireguard public private key pair.
 *
 * @example
 * import { generateKeyPair } from "the-wireguard-effect/WireguardKey"
 * const { privateKey, publicKey } = generateKeyPair()
 *
 * @since 1.0.0
 * @category Crypto
 */
export declare const generateKeyPair: {
    (): {
        privateKey: WireguardKey;
        publicKey: WireguardKey;
    };
};
export default WireguardKey;
//# sourceMappingURL=WireguardKey.d.ts.map